-- Correlated columns in Northwind..Orders

-- select OrderDate, ShippedDate
-- from Northwind..Orders
go

-- Is the fraction of null ShippedDate values
-- consistent across the table?

create proc NullShippedDateFraction (
  @percentOfOrderDatesFromTop int
) as
  declare @sql nvarchar(1000)
  set @sql = '
select 
  sum(case when ShippedDate is null then 1.0 else 0 end)/count(*)
  -- count of null shippedDate values divided by the full count
  as [NullShippedDateFraction in first $ percent of rows by OrderDate]
from (  -- A fraction of table starting at top (ordered by OrderDate)
  select top $ percent OrderDate, ShippedDate
  from Northwind..Orders
  order by OrderDate
) T
'
  set @sql = replace(@sql,'$',@percentOfOrderDatesFromTop)
  exec (@sql)
go

exec NullShippedDateFraction @percentOfOrderDatesFromTop = 100
exec NullShippedDateFraction @percentOfOrderDatesFromTop = 99
exec NullShippedDateFraction @percentOfOrderDatesFromTop = 98
exec NullShippedDateFraction @percentOfOrderDatesFromTop = 95
exec NullShippedDateFraction @percentOfOrderDatesFromTop = 90
exec NullShippedDateFraction @percentOfOrderDatesFromTop = 80
go

drop proc NullShippedDateFraction