set nocount on
go

Use Connections
GO

-- Create a Northwind..Orders - like table
CREATE TABLE Orders (
	OrderID int IDENTITY (10000, 1) NOT NULL
    PRIMARY KEY CLUSTERED,
	CustomerID nchar (5),
	EmployeeID int NULL ,
	OrderDate datetime NULL ,
	ShippedDate datetime NULL ,
	ShipNotes nvarchar (4000)
)
go

-- Create a procedure to populate this
-- table with various distributions of values
create procedure PopulateOrders (
  @rows int,
    -- total number of rows to insert
  @NotesLength int,
    -- how much filler to put in
  @EmployeeCount int,
    -- we might try some grouping or other tests
  @FirstFracShipped decimal(8,7),
    -- fraction of earliest orders that have all been shipped
  @FractionUnshipped decimal(8,7)  
    -- total fraction of orders in table that are not shipped
) as

  if @FractionUnshipped > 1.0 - @FirstFracShipped begin
    print '@FirstFracShipped + @FractionUnshipped cannot exceed 1.0'
    print 'Retry with different values'
    return
  end
begin tran
  declare @yearsAdd int
  set @yearsAdd = 0
  -- We'll insert copy after copy of Northwind..Orders,
  -- with dates advaced by 2 years each time.

  declare @rowCount int
  set @rowCount = @rows
  -- @rows_left_to_be_inserted

  while @rowCount > 0 begin
    insert into Orders
    select
      CustomerID,
      cast(rand()*@EmployeeCount as int)+1,
        -- uniform distribution from 1 to @EmployeeCount
      DateAdd(year, @yearsAdd, OrderDate),
        -- OrderDate with 2-year advance each time around
      DateAdd(year, @yearsAdd, OrderDate)
-- abs(binary_checksum(newid()))%1000
-- is a random integer from 0 to 999
         + square(abs(binary_checksum(newid()))%1000*0.001)*80,
        -- OrderDate + up to 80 days, with values clustered close to OrderDate
      replicate(left(newid(),2),@NotesLength*cast(1.5*rand() as int))
        -- Notes lengths will vary with each chunk of rows inserted
    from Northwind..Orders
    where OrderID-10247 <= @rowCount
      -- don't overfill table
    set @rowCount = @rowCount - @@rowCount
      -- adjust how many rows left to insert
    set @yearsAdd = @yearsAdd + 2
      -- advance year for next batch
  end

  -- all rows inserted so far have non-null ShippedDate
  -- change the right number to null (in the right place)
  -- randomly
  update Orders set
    ShippedDate =
      case when abs(binary_checksum(newid()))%1000
         < 1000e0*(@FractionUnshipped/(1e0-@FirstFracShipped))
      then NULL else ShippedDate end
  where OrderID-@rows+1 >= @rows*@FractionUnshipped
commit tran
go

truncate table Orders

exec PopulateOrders
  @rows = 15000,
  @NotesLength = 900,
  @EmployeeCount = 5,
  @FirstFracShipped = 0.90,
  @FractionUnshipped = 0.01

GO
-- Add at least the indexes we had in Northwind
CREATE INDEX Orders_OrderDate ON Orders(OrderDate)
CREATE INDEX Orders_ShippedDate ON Orders(ShippedDate)
CREATE INDEX Orders_CustomerID ON Orders(CustomerID)
GO


--Drop proc PopulateOrders
--Drop table Orders

